pub enum CDiskType {
Either,
Directory,
File,
}Expand description
Identifies the type of src on the disk when attempting to see if it disk_exists or not.
Variants
Either
Does not matter the type, just does it exist or not.
Directory
Only true if it is a directory.
File
Only true if it is a file.