storage_init

Function storage_init 

pub fn storage_init()
Responsible for initializing the storage for the module. This must be called first before the module can be used or a panic will occur. It will read previous storage from disk and bring it into memory for later access.

Example:

codemelted::storage_init();
---
title: Storage Use Case Object Hierarchy
---
classDiagram
  direction TB
  namespace codemelted {
    class CObject
    class disk_write_file
    class disk_read_file
    class storage_save_file
    class storage_init
    class storage_clear
    class storage_get
    class storage_length
    class storage_remove
    class storage_set
  }
  storage_init --> disk_read_file: calls
  storage_init --> CObject: initializes
  storage_save_file --> CObject: reads from
  storage_save_file --> disk_write_file: calls
  storage_clear --> storage_save_file: updates
  storage_get --> CObject: reads from
  storage_length --> CObject: reads from
  storage_remove --> storage_save_file: updates
  storage_set --> storage_save_file: updates